/*
 * Generic accessor functionality.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "accessor.h"

#include <string.h>



Accessor::Accessor(fileid_t fileid, offset_t size)
: _size(size), fileid(fileid)
{
}

Accessor::~Accessor()
{
}

/* Return the size of the file. */

offset_t Accessor::get_size()
{
    return _size;
}

/* Update the size of the file. */

void Accessor::set_size(offset_t size)
{
    _size = size;
}

/* Perform any closing operation on the file. */

void Accessor::close()
{
}

/* Perform any opening operation on the file. */

void Accessor::open()
{
}

/* Data transfer methods. */

void Accessor::fill(Flexpage *flexpage)
{
    /* Filling completely beyond the end of file should produce an empty
       flexpage. This could potentially be a shared read-only flexpage that
       would be replaced by an independent writable flexpage if ever written. */

    if (flexpage->base_offset < _size)
        fill_populated(flexpage);
    else
        memset((void *) flexpage->base_addr, 0, flexpage->size);
}

void Accessor::flush(Flexpage *flexpage)
{
    /* Flushing completely beyond the end of file should discard the
       flexpage. */

    if (flexpage->base_offset < _size)
        flush_populated(flexpage);
}

/* Data transfer helper methods. */

void Accessor::fill_populated(Flexpage *flexpage)
{
    (void) flexpage;
}

void Accessor::flush_populated(Flexpage *flexpage)
{
    (void) flexpage;
}

// vim: tabstop=4 expandtab shiftwidth=4
