/*
 * A pipe accessor merely resetting allocated memory for use.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "pipe_accessor.h"

#include <string.h>

PipeAccessor::PipeAccessor()
: Accessor(0)
{
}

/* Perform any closing operation on the file. */

void PipeAccessor::close()
{
}

/* Perform any opening operation on the file. */

void PipeAccessor::open()
{
}

/* Data transfer helper methods. */

void PipeAccessor::fill_populated(Flexpage *flexpage)
{
    offset_t filepos = flexpage->base_offset;
    offset_t addr = flexpage->base_addr;

    /* Tag the region with file state. */

    flexpage->region->fill(fileid, filepos);

    /* File the flexpage with zero. */

    memset((void *) addr, 0, flexpage->size);
}

void PipeAccessor::flush_populated(Flexpage *flexpage)
{
    flexpage->region->flush();
}

// vim: tabstop=4 expandtab shiftwidth=4
